.. raw:: html

    <p align="center">
        <a href="#readme">
            <img alt="logo" width="70%" src="https://raw.githubusercontent.com/DevconX/Malaya/master/session/towns-of-malaya.jpg">
        </a>
    </p>
    <p align="center">
        <a href="https://pypi.python.org/pypi/malaya"><img alt="cpu downloaded" src="https://img.shields.io/pypi/dm/malaya.svg"></a>
        <a href="https://pypi.python.org/pypi/malaya"><img alt="gpu downloaded" src="https://img.shields.io/pypi/dm/malaya-gpu.svg"></a>
        <a href="https://pypi.python.org/pypi/malaya"><img alt="Pypi version" src="https://badge.fury.io/py/malaya.svg"></a>
        <a href="https://pypi.python.org/pypi/malaya"><img alt="Python3 version" src="https://img.shields.io/pypi/pyversions/malaya.svg"></a>
        <a href="https://github.com/huseinzol05/Malaya/blob/master/LICENSE"><img alt="MIT License" src="https://img.shields.io/badge/License-MIT-yellow.svg"></a>
        <a href="https://malaya.readthedocs.io/"><img alt="Documentation" src="https://readthedocs.org/projects/malaya/badge/?version=latest"></a>
        <a href="https://travis-ci.org/huseinzol05/Malaya"><img alt="Build status" src="https://travis-ci.org/huseinzol05/Malaya.svg?branch=master"></a>

    </p>

=========

**Malaya** is a Natural-Language-Toolkit library for bahasa Malaysia, powered by Deep Learning Tensorflow.

Documentation
--------------

Proper documentation is available at https://malaya.readthedocs.io/

Installing from the PyPI
----------------------------------

CPU version
::

    $ pip install malaya

GPU version
::

    $ pip install malaya-gpu

Only **Python 3.6.x** is supported.

Features
--------

-  **Emotion Analysis**

   From BERT, Fast-Text, Dynamic-Memory Network, Sparse Tensorflow, Attention Neural Network to build deep emotion analysis models.
-  **Entities Recognition**

   Latest state-of-art CRF deep learning models to do Naming Entity Recognition.

-  **Language Detection**

   using Multinomial, SGD, XGB, Fast-text N-grams deep learning to distinguish Malay, English, and Indonesian.
-  **Normalizer**

   using local Malaysia NLP researches to normalize any
   bahasa texts.
-  **Num2Word**

   Convert from numbers to cardinal or ordinal representation.
-  **Part-of-Speech Recognition**

   Latest state-of-art CRF deep learning models to do Naming Entity Recognition.
-  **Dependency Parsing**

   Latest state-of-art CRF deep learning models to do analyzes the grammatical structure of a sentence, establishing relationships between words.
-  **Sentiment Analysis**

   From BERT, Fast-Text, Dynamic-Memory Network, Sparse Tensorflow, Attention Neural Network to build deep sentiment analysis models.
-  **Spell Correction**

   Using local Malaysia NLP researches to auto-correct any bahasa words.
-  Stemmer
-  **Subjectivity Analysis**

   From BERT, Fast-Text, Dynamic-Memory Network, Sparse Tensorflow, Attention Neural Network to build deep subjectivity analysis models.
-  **Summarization**

   Using skip-thought with attention state-of-art to give precise unsupervised summarization.
-  **Topic Modelling**

   Provide LDA2Vec, LDA, NMF and LSA interface for easy topic modelling with topics visualization.
-  **Topic and Influencers Analysis**

   Using deep and machine learning models to understand topics and Influencers similarity in sentences.
-  **Toxicity Analysis**

   From BERT, Fast-Text, Dynamic-Memory Network, Attention Neural Network to build deep toxicity analysis models.
-  **Word2Vec**

   Provide pretrained bahasa wikipedia and bahasa news Word2Vec, with easy interface and visualization.

License
--------

.. |License| image:: https://app.fossa.io/api/projects/git%2Bgithub.com%2Fhuseinzol05%2FMalaya.svg?type=large
   :target: https://app.fossa.io/projects/git%2Bgithub.com%2Fhuseinzol05%2FMalaya?ref=badge_large

|License|
